! ----------------------------------------------------------------------
! *   Montecallo simulation of diffusion                               *
! ----------------------------------------------------------------------

   program diff_monte

      use mod_para

      implicit none

      real(8), allocatable:: dx(:)
      real(8), allocatable:: x(:), xL(:)
      real(8):: r1(12), rnorm
      real(8):: t
      integer:: it,  i,  iL,  j
      integer:: nt,  nf, nif
      character(60):: apara

!  ****  read parameters  ****

      open ( 10, file='diff_para.dat', status='old' )

      read ( 10,* )
      read ( 10,* ) apara      
      read ( 10,* ) NP
      write ( 6,* ) apara      
      write ( 6,* ) NP
      read ( 10,* ) apara      
      read ( 10,* ) nt
      write ( 6,* ) apara      
      write ( 6,* ) nt
      read ( 10,* ) apara      
      read ( 10,* ) dt
      write ( 6,* ) apara      
      write ( 6,* ) dt
      read ( 10,* ) apara      
      read ( 10,* ) Lx
      write ( 6,* ) apara      
      write ( 6,* ) Lx
      read ( 10,* ) apara      
      read ( 10,* ) nx
      write ( 6,* ) apara      
      write ( 6,* ) nx
      read ( 10,* ) apara      
      read ( 10,* ) nif
      write ( 6,* ) apara      
      write ( 6,* ) nif

!  ****  allocate dimension variables  ****

      allocate ( x(NP), dx(NP) )
      allocate ( xL(-nx:nx) )

!  ****  interval length for distribution function  ****

      dLx = Lx / dfloat( nx )

      write ( 6,* ) dLx

!  ****  coordinates of distribution function

      do iL = -nx,nx
        xL(iL) = dLx * dfloat( iL )
      end do

!  ****  set particles at inital position  ****

      x(:) = 0.0d0
      call ranseed( )

      it = 0
      nf = 0

!  ****  calculate mean, rms, and distribution function  ****

      open ( 20, file='t_sig_dis.dat' )

      call medisp ( x,  t,  it, nif )
      call distrib( x,  xL, it, nf )

!  ****  loop of time marching  ********************************************************

      do it = 1,nt

        t = t + dt

!  ****  calculate increment of particle movement  ****

        do i = 1,NP

!  ****  calculate normal random number  ****

          rnorm = 0.0d0
          call random_number( r1 )
          do j = 1,12
            rnorm = rnorm + r1( j )
          end do

          dx(i) = rnorm - 6.0d0

        end do

!  ****  advance particle  ****

        x(:) = x(:) + dx(:)


!  ****  output to file  ****

        call medisp ( x,  t,  it, nif )

        if ( mod( it,nif ) == 0 ) then
          nf = nf + 1 
          call distrib( x,  xL, it, nf )
        end if

      end do

      call thdist( xL, t,  it, nf )

!  ****  end of time marching  ********************************************************

      close ( 20 )
      stop

   end program diff_monte

